==> monica-4.0.0.tgz: www/monica/resources/lang/it/journal.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'journal_rate' => 'Com\'è andata la tua giornata? Puoi votare una volta al giorno.',
    'journal_come_back' => 'Grazie. Ritorna domani per valutare di nuovo la tua giornata.',
    'journal_description' => 'Nota: il diario mostra sia voci inserite manualmente che voci generate automaticamente come le Attività svolte con i tuoi contatti. Puoi eliminare le voci manuali, ma per quelle automatiche devi eliminarla direttamente dalla pagina del contatto.',
    'journal_add' => 'Scrivi nel diario',
    'journal_edit' => 'Modifica una voce del diario',
    'journal_empty' => 'Diario vuoto',
    'journal_created_at' => 'Creato il {date}',
    'journal_created_automatically' => 'Creata automaticamente',
    'journal_entry_type_journal' => 'Voce del diario',
    'journal_entry_type_activity' => 'Attività',
    'journal_entry_rate' => 'Hai votato la tua giornata.',
    'journal_add_comment' => 'Ti interessa aggiungere un commento? (facoltativo)',
    'journal_show_comment' => 'Visualizza commento',
    'entry_delete_success' => 'La pagina del diario è stata rimossa.',
    'journal_add_title' => 'Titolo (facoltativo)',
    'journal_add_date' => 'Data',
    'journal_add_post' => 'Testo',
    'journal_add_cta' => 'Salva',
    'journal_blank_cta' => 'Scrivi qualcosa nel diario',
    'journal_blank_description' => 'Il diario ti permette di appuntare cose che ti succedono, e ricordarle.',
    'delete_confirmation' => 'Sei sicuro di voler rimuovere questa pagina dal diario?',
];

==> monica-4.1.2p0.tgz: www/monica/resources/lang/it/journal.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'journal_rate' => 'Com\'è andata la tua giornata? Puoi votare una volta al giorno.',
    'journal_come_back' => 'Grazie. Ritorna domani per valutare di nuovo la tua giornata.',
    'journal_description' => 'Nota: il diario mostra sia voci inserite manualmente che voci generate automaticamente come le Attività svolte con i tuoi contatti. Puoi eliminare le voci manuali, ma per quelle automatiche devi eliminarla direttamente dalla pagina del contatto.',
    'journal_add' => 'Scrivi nel diario',
    'journal_edit' => 'Modifica una voce del diario',
    'journal_empty' => 'Diario vuoto',
    'journal_created_at' => 'Creato il {date}',
    'journal_created_automatically' => 'Creata automaticamente',
    'journal_entry_type_journal' => 'Voce del diario',
    'journal_entry_type_activity' => 'Attività',
    'journal_entry_rate' => 'Hai votato la tua giornata.',
    'journal_add_comment' => 'Ti interessa aggiungere un commento? (facoltativo)',
    'journal_show_comment' => 'Visualizza commento',
    'entry_delete_success' => 'La pagina del diario è stata rimossa.',
    'journal_add_title' => 'Titolo (facoltativo)',
    'journal_add_date' => 'Data',
    'journal_add_post' => 'Testo',
    'journal_add_cta' => 'Salva',
    'journal_blank_cta' => 'Scrivi qualcosa nel diario',
    'journal_blank_description' => 'Il diario ti permette di appuntare cose che ti succedono, e ricordarle.',
    'delete_confirmation' => 'Sei sicuro di voler rimuovere questa pagina dal diario?',
    'apply_filter' => 'Apply filter',
    'start_date' => 'Start Date',
    'end_date' => 'End Date',
    'per_page' => 'Per Page',
    'sort_order' => 'Sort By Created At',
    'ascending' => 'Ascending',
    'descending' => 'Descending',
];
